@@ -38,7 +38,7 @@ src.cfg.initialise("default.config", None,
 # i18n should be imported very early in program init because it setup
 # the _ and _i functions for the whole program.
 import src.i18n
-src.i18n.setup(".")
+src.i18n.setup(".", src.cfg.get_string("app/lc_messages"))
 
 import src.mainwin
 
