@@ -75,6 +75,8 @@ class LessonbasedTeacher(Teacher):
     def __init__(self, exname, app):
         Teacher.__init__(self, exname, app)
         self.m_P = None
+        # The file name, not a file object
+        self.m_lessonfile = None
         self.m_question = None
     def is_test_complete(self):
         """
@@ -86,40 +88,41 @@ class LessonbasedTeacher(Teacher):
         Shared between harmonic and melodic interval.
         """
         self.m_statistics.exit_test_mode()
-    def set_lessonfile(self, lessoncollection, lessonfile):
+    def set_lessonfile(self, lessonfile):
         """
-        Set the config variables 'lessonfile' and 'lessoncollection'
-        Parse the lesson file and save the statistics.
+        Set the variable 'm_lessonfile' and
+        parse the lesson file and save the statistics.
         """
         if lessonfile is not None \
-                and lessonfile == self.get_string('lessonfile'):
+                and lessonfile == self.m_lessonfile:
             new_file = 0
         else:
             new_file = 1
-        if lessoncollection:
-            self.set_string('lessoncollection', lessoncollection)
-        if lessonfile:
-            self.set_string('lessonfile', lessonfile)
+        self.m_lessonfile = lessonfile
         self.parse_lessonfile()
         if self.m_P and self.m_statistics:
-            self.m_statistics.lessonfile_changed(
-             self.get_string('lessoncollection'), self.get_string('lessonfile'))
+            self.m_statistics.lessonfile_changed(self.m_lessonfile)
     def parse_lessonfile(self):
         self.m_question = None
         self.q_status = const.QSTATUS_NO
-        if not self.get_string('lessonfile'):
+        if not self.m_lessonfile:
             self.m_P = None
             return
-        fn = self.m_app.lessonfile_manager.get_complete_filename(
-             self.get_string('lessoncollection'),
-             self.get_string('lessonfile'))
+        self.m_P = None
         try:
-            self.m_P = self.lessonfileclass(fn, self)
+            self.m_P = self.lessonfileclass(self.m_lessonfile, self)
         except IOError:
             self.m_app.m_ui.display_error_message(
 """There was an IOError while trying to parse a lesson file. The cause was probably you deleting or renaming a lesson file. Please don't do this while Solfege is running. The program is still a little fragile. 
 
 You really should reastart the program now.""")
+            return
+        except mpd.MpdException, e:
+            self.m_app.m_ui.display_exception_message(e, msg="Error parsing lessonfile '%s':" % self.m_lessonfile)
+            return
+        except lessonfile.LessonfileException, e:
+            self.m_app.m_ui.display_exception_message(e, __file__)
+            return
         if filter(lambda q: q['music'].m_musictype == 'cmdline',
                   self.m_P.m_questions):
             run = gu.dialog_yesno(_("The lessonfile contain potentially dangerous code because it run external programs. Run anyway?"))
@@ -250,7 +253,6 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
         vbox.pack_start(self.practise_box, False)
         self.g_lesson_heading = gtk.Label()
         self.practise_box.pack_start(self.g_lesson_heading, padding=18)
-        self.g_lesson_heading.show()
 
         self.action_area = gtk.HBox()
         self.action_area.show()
@@ -291,6 +293,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
     def set_lesson_heading(self, txt):
         self.g_lesson_heading.set_text('<span size="large"><b>%s</b></span>' % txt)
         self.g_lesson_heading.set_use_markup(True)
+        self.g_lesson_heading.show()
     def on_start_practise(self):
         """Dummy function that child classes can override.
         """
@@ -370,6 +373,28 @@ class IntervalGui(Gui):
         self.g_repeat = gu.bButton(self.action_area, _("_Repeat"), self.repeat_question)
         self.g_repeat.set_sensitive(False)
         self.setup_key_bindings()
+    def _create_select_inputwidget_gui(self):
+        """
+        This will be called by HarmonicInterval and MelodicInterval
+        constructor
+        """
+        hbox = gu.bHBox(self.config_box, False)
+        hbox.set_spacing(gnome.ui.PAD_SMALL)
+        gu.bLabel(hbox, _("Input interface:"), False)
+
+        combo = gtk.combo_box_new_text()
+        for i in range(len(inputwidgets.inputwidget_names)):
+            combo.append_text(inputwidgets.inputwidget_names[i])
+        if self.get_int('inputwidget') < len(inputwidgets.inputwidget_names):
+            combo.set_active(self.get_int('inputwidget'))
+        else:
+            combo.set_active(0)
+        combo.connect('changed', lambda w: self.use_inputwidget(w.get_active()))
+        hbox.pack_start(combo, False)
+
+        self.g_disable_unused_buttons = gu.nCheckButton(self.m_exname,
+                    'disable_unused_intervals', _("_Disable unused buttons"))
+        hbox.pack_start(self.g_disable_unused_buttons)
     def select_inputwidget(self):
         """
         This will be called by HarmonicInterval and MelodicInterval
