@@ -36,7 +36,7 @@ def check_rcfile():
     """See default.config for rcfileversion values, meanings and
     a description of how to add config variables.
     """
-    rcfileversion = 10
+    rcfileversion = 11
     if cfg.get_int("app/rcfileversion") > rcfileversion:
         cfg.drop_user_config()
         return
@@ -74,6 +74,12 @@ def check_rcfile():
         cfg.del_key("harmonicinterval/lowest_tone")
     if cfg.get_int("app/rcfileversion") <= 9:
         cfg.del_section("mainwin")
+    if cfg.get_int("app/rcfileversion") <= 10:
+        cfg.del_section("lessoncollections")
+        cfg.del_key("config/lessoncollections")
+        for n in cfg.iterate_sections():
+            cfg.del_key("%s/lessoncollection" % n)
+            cfg.del_key("%s/lessonfile" % n)
     cfg.set_int("app/rcfileversion", rcfileversion)
 
 class SolfegeApp(cfg.ConfigUtils):
@@ -186,8 +192,7 @@ It is also possible that the OS sound setup is incorrect.
             self.create_teacher(module)
             self.m_ui.initialise_exercise(self.m_teachers[module])
         self.m_teachers[module].set_lessonfile(
-            self.lessonfile_manager.get(lesson_id, 'lessoncollection'),
-            self.lessonfile_manager.get(lesson_id, 'lessonfile'))
+            self.lessonfile_manager.get(lesson_id, 'filename'))
         self.m_ui.activate_exercise(module, urlobj)
         self.m_running_exercise = module
         self.m_teachers[module].g_view = self.m_ui.box_dict[module]
@@ -243,20 +248,18 @@ It is also possible that the OS sound setup is incorrect.
         if urlobj.action == 'all-lessonfiles':
             self.m_ui.display_html(self.lessonfile_manager.m_htmldoc)
             return
-        if urlobj.lessonfile:
-            filepath = os.path.join(self.get_string('lessoncollections/%s' % urlobj.lessoncollection), urlobj.lessonfile)
-            if not os.path.isfile(gethomedir.expanduser(filepath)):
-                self.m_ui.display_error_message("Lessonfile not found:\n%s" % filepath)
-                return
-        # the Url class does not know anything about lesson ids, so
-        # it reports it as lessoncollection without lessonfile.
-        if urlobj.lessoncollection and not urlobj.lessonfile:
-            self.practise_lesson_id(urlobj.lessoncollection)
+        # the Url class does not know anything about lesson ids, but we
+        # assume that lesson_ids don't include the '/' character.
+        if '/' not in urlobj.lessonfile:
+            self.practise_lesson_id(urlobj.lessonfile)
             return
+        if urlobj.lessonfile:
+            if not os.path.isfile(urlobj.lessonfile):
+                self.m_ui.display_error_message("Lessonfile not found:\n%s" % urlobj.lessonfile)
+                return
         p = lessonfile.LessonfileCommon(None)#FIXME it would have been
         # better if we didn't have to parse the file twice.
-        p.parse_file(self.lessonfile_manager.get_complete_filename(
-            urlobj.lessoncollection, urlobj.lessonfile))
+        p.parse_file(urlobj.lessonfile)
         self._practise_lesson_id(p.header.lesson_id, urlobj)
         # This loop changes variables in the lesson file header if they
         # have set values in the url.
@@ -272,11 +275,6 @@ It is also possible that the OS sound setup is incorrect.
         """
         exec("import %s" % modulename)
         self.m_teachers[modulename] = locals()[modulename].Teacher(modulename, self)
-        return
-        if issubclass(locals()[modulename].Teacher, abstract.LessonbasedTeacher):
-            self.m_teachers[urlobj.exercisemodule] = locals()[modulename].Teacher(urlobj.exercisemodule, self, urlobj.lessoncollection, urlobj.lessonfile, urlobj.config)
-        else:
-            self.m_teachers[urlobj.exercisemodule] = locals()[modulename].Teacher(urlobj.exercisemodule, self, urlobj.config)
     def reset_exercise(self, w=None):
         """
         Call on_end_practise, and then on_start_practise in
