@@ -462,7 +462,7 @@ class Gui(abstract.LessonbasedGui):
             # Invalid key variable or music code goes here.
             exception_cleanup()
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
+                self.m_t.m_P._idx, self.m_t.m_lessonfile, e)
     def on_start_practise(self):
         self.m_t.m_custom_mode = self.get_bool('gui/expert_mode')
         for question in self.m_t.m_P.m_questions:
