@@ -83,7 +83,7 @@ class Gui(abstract.LessonbasedGui):
         except mpd.MpdException, e:
             self.exception_cleanup()
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
         except lessonfile.LessonfileException, e:
             self.exception_cleanup()
             self.g_win.display_exception_message(e, __file__)
@@ -99,7 +99,7 @@ class Gui(abstract.LessonbasedGui):
         except mpd.MpdException, e:
             self.exception_cleanup()
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
         except lessonfile.LessonfileException, e:
             self.exception_cleanup()
             self.g_win.display_exception_message(e, __file__)
@@ -121,7 +121,7 @@ class Gui(abstract.LessonbasedGui):
             # if the user are fast, that the last question is still playing.
             soundcard.synth.stop()
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
     def on_end_practise(self):
         self.m_t.end_practise()
     def show_answer(self, widget=None):
@@ -135,7 +135,7 @@ class Gui(abstract.LessonbasedGui):
                             self.get_int('config/feta_font_size=20'))
         except mpd.MpdException, e:
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
     def _update(self):
         """
         Updates the buttons above the action_area where you have
@@ -154,11 +154,10 @@ class Gui(abstract.LessonbasedGui):
             except mpd.MpdException, e:
                 soundcard.synth.stop()
                 self.g_win.display_question_music_error_message(
-                   self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+                   self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
         for i in self.g_partbox.get_children():
             i.destroy()
-        # if the user selects a collection without lessonfiles, or if
-        # the lessonfile was invalid, m_P could be None
+        # if the lessonfile was invalid, m_P could be None
         if self.m_t.m_P and self.m_t.m_P.m_questions:
             self.g_question_title.set_text(self.m_t.m_P.get_name())
             v = self.m_t.m_P.get_breakpoints()
@@ -194,7 +193,7 @@ class Gui(abstract.LessonbasedGui):
     def update_gui_after_lessonfile_change(self):
         self.m_t.q_status = const.QSTATUS_NEW
         if not self.m_t.m_P.m_questions:
-            self.g_win.display_error_message(_("The lesson file '%s' contains no questions.") % self.get_string('lessonfile'))
+            self.g_win.display_error_message(_("The lesson file '%s' contains no questions.") % self.m_t.m_lessonfile)
             self.g_play.set_sensitive(False)
             self.g_show.set_sensitive(False)
             self.g_go_back.set_sensitive(False)
@@ -210,7 +209,7 @@ class Gui(abstract.LessonbasedGui):
             self.display_start_of_music()
         except mpd.MpdException, e:
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
             self.m_t.q_status = const.QSTATUS_NO
             self.g_play.set_sensitive(False)
             self.g_show.set_sensitive(False)
