@@ -39,6 +39,10 @@ class HelpBrowser(gtk.Window):
         self.g_ui_manager = gtk.UIManager()
         self.g_ui_manager.insert_action_group(self.g_action_group, 0)
         self.g_ui_manager.add_ui_from_file("helpbrowser.xml")
+        self.add_accel_group(self.g_ui_manager.get_accel_group())
+        self.g_ui_manager.get_accel_group().connect_group(gtk.keysyms.W,
+           gtk.gdk.CONTROL_MASK, 0,
+           self.hide_on_delete)
         self.vbox = gtk.VBox()
         self.add(self.vbox)
         self.vbox.pack_start(self.g_ui_manager.get_widget("/HelpToolbar"), False)
