@@ -23,7 +23,6 @@ import gettext
 import locale
 import os
 import sys
-import cfg
 
 def _i(s):
     """
@@ -59,10 +58,9 @@ def langs():
             retval.append(s)
     return retval
 
-def setup(prefix):
+def setup(prefix, config_locale=None):
     # Gettext and gtk+ chech the variables in this order.
     varlist = ('LANGUAGE', 'LC_ALL', 'LC_MESSAGES', 'LANG')
-    config_locale = cfg.get_string("app/lc_messages")
     if not config_locale:
         config_locale = 'system default'
     if config_locale != 'system default':
