@@ -356,7 +356,7 @@ class Gui(abstract.LessonbasedGui):
         except mpd.MpdException, e:
             exception_cleanup()
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'),
+                self.m_t.m_P._idx, self.m_t.m_lessonfile,
                 e, __file__)
         except osutils.RunExternalFailed, e:
             exception_cleanup()
