@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2004, 2005  Tom Cato Amundsen
+# Copyright (C) 2004, 2005, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ gtk.stock_add([('solfege-notehead', _("Add noteheads"), 0, 0, ''),
                ('solfege-double-flat', _("Add double-flat"), 0, 0, ''),
                ('solfege-erase', _("Delete tone"), 0, 0, ''),
                ])
-app_version = "0.1.3"
+app_version = "0.1.4"
 
 class HelpWindow(gtk.Window):
     def __init__(self, parent):
@@ -155,7 +155,7 @@ class EditorLessonfile(object):
     def __init__(self):
         self.m_filename = None
         self.m_changed = False
-        self.header = lessonfile._Header({'content': ['chord']})
+        self.header = lessonfile._Header({'module': 'chord'})
         self.m_questions = [dataparser.Question()]
         self.m_questions[-1]['music'] = lessonfile.Music("", "chord")
         self.m_questions[-1]['name'] = ""
@@ -208,9 +208,9 @@ class MainWin(gtk.Window):
         self.g_title = gtk.Entry()
         cvbox.pack_start(gu.hig_label_widget(_("File title:"), self.g_title, 
                         sizegroup))
-        self.g_content_chord = gtk.CheckButton("chord")
-        self.g_content_chord_voicing = gtk.CheckButton("chord-voicing")
-        self.g_content_idbyname = gtk.CheckButton("id-by-name")
+        self.g_content_chord = gtk.RadioButton(None, "chord")
+        self.g_content_chord_voicing = gtk.RadioButton(self.g_content_chord, "chord-voicing")
+        self.g_content_idbyname = gtk.RadioButton(self.g_content_chord, "id-by-name")
         box = gtk.HBox()
         box.pack_start(self.g_content_chord)
         box.pack_start(self.g_content_chord_voicing)
@@ -239,9 +239,9 @@ class MainWin(gtk.Window):
         self.set_navinfo()
         self.g_title.set_text(self.m_P.header.title)
         self.g_random_transpose.set_text(str(self.m_P.header.random_transpose))
-        self.g_content_chord.set_active("chord" in self.m_P.header.content)
-        self.g_content_chord_voicing.set_active("chord-voicing" in self.m_P.header.content)
-        self.g_content_idbyname.set_active("id-by-name" in self.m_P.header.content)
+        {'chord': self.g_content_chord,
+         'chordvoicing': self.g_content_chord_voicing,
+         'idbyname': self.g_content_idbyname}[self.m_P.header.module].set_active(True)
     def set_navinfo(self):
         if self.m_P.m_filename:
             self.set_title(self.m_P.m_filename)
@@ -263,15 +263,13 @@ class MainWin(gtk.Window):
             self.m_P.m_questions[-1]['name'] = ""
             self.m_P._idx = 0
 
-        for c in self.m_P.header.content:
-            if c not in ('id-by-name', 'chord', 'chord-voicing'):
+        if self.m_P.header.module not in ('idbyname', 'chord', 'chordvoicing'):
                 dialog = gtk.MessageDialog(self, gtk.DIALOG_MODAL,
                     gtk.MESSAGE_ERROR, gtk.BUTTONS_CLOSE,
-                    _("Lesson file content '%s' is not supported yet. Cannot edit this file.") % c)
+                    _("The exercise module '%s' is not supported yet. Cannot edit this file.") % c)
                 dialog.run()
                 dialog.destroy()
                 self.m_P = EditorLessonfile()
-                break
         self.update_appwin()
     def file_open_cb(self, *v):
         dialog = gtk.FileChooserDialog(_("Open..."), self,
@@ -331,12 +329,14 @@ class MainWin(gtk.Window):
         ofile = file(self.m_P.m_filename, 'w')
         ofile.write("# Creator: GNU Solfege lesson file editor %s\n\n"
                     % app_version)
-        ofile.write("header {\n    content = %s\n" % ", ".join(self.m_P.header.content))
+        ofile.write("header {\n    module = %s\n" % self.m_P.header.module)
         if type(self.m_P.header.random_transpose) == list:
             ofile.write("    random_transpose = %s, %s, %s\n" % (self.m_P.header.random_transpose[0],
                             self.m_P.header.random_transpose[1], self.m_P.header.random_transpose[2]))
         else:
-            ofile.write("    random_transpose = %s\n" % str(self.m_P.header.random_transpose))
+            ofile.write("    random_transpose = yes\n")
+        if self.m_P.header.lesson_id:
+            ofile.write('    lesson_id = "%s"\n' % self.m_P.header.lesson_id)
         ofile.write('    title = "%s"\n}\n' % self.m_P.header.title)
         for q in self.m_P.m_questions:
             print >> ofile, 'question {'
@@ -431,13 +431,12 @@ edit your hand written lesson files with this program.</p>
         self.m_P.m_questions[self.m_P._idx]['name'] = self.g_question_name.get_text()
         self.m_P.header.title = self.g_title.get_text()
         self.m_P.header.random_transpose = eval(self.g_random_transpose.get_text())
-        self.m_P.header.content = []
         if self.g_content_chord.get_active():
-            self.m_P.header.content.append('chord')
+            self.m_P.header.module = 'chord'
         if self.g_content_chord_voicing.get_active():
-            self.m_P.header.content.append('chord-voicing')
+            self.m_P.header.module = 'chordvoicing'
         if self.g_content_idbyname.get_active():
-            self.m_P.header.content.append('id-by-name')
+            self.m_P.header.module = 'idbyname'
     def on_displayer_clicked(self, ed, steps):
         self.m_P.m_changed = True
         notename = ("c", "d", "e", "f", "g", "a", "b")[6-(steps % 7)]
