@@ -34,10 +34,7 @@ class MyOptionParser(optparse.OptionParser):
     def print_help(self, file=None):
         if file is None:
             file = sys.stdout
-        encoding = file.encoding
-        if not encoding:
-            encoding = "iso-8859-1"
-        file.write(self.format_help().encode(encoding, 'replace'))
+        file.write(self.format_help().encode(file.encoding, 'replace'))
 
 opt_parser = MyOptionParser()
 opt_parser.add_option('-v', '--version', action='store_true', dest='version')
@@ -182,6 +179,7 @@ import chordvoicing
 import harmonicinterval
 import melodicinterval
 import singinterval
+import nameinterval
 
 import idbyname
 import dictation
@@ -289,7 +287,6 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
           ('EditMenu', None, _("_Edit")),
           ('TreeEditor', None, _('Learning tree'), None, None,
             self.do_tree_editor),
-          ('PractiseMenu', None, _("_Practise")),
           ('TestsMenu', None, _("_Tests")),
           ('OpenPreferencesWindow', 'gtk-preferences', None, '<ctrl>F12', None,
             self.open_preferences_window),
@@ -360,36 +357,38 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         if self.m_practise_and_test_merge_id:
             self.g_ui_manager.remove_ui(self.m_practise_and_test_merge_id)
             self.g_ui_manager.ensure_update()
-        s = """
-<menubar name='Menubar'>
- <menu action='PractiseMenu'>"""
+        s = "<menubar name='Menubar'>"
         tests = "<menu action='TestsMenu'>"
-        for topic in self.m_tree.m_topics:
-            s += "<menu action='%s'>" % topic['name']
-            tests += "<menu action='TEST_%s'>" % topic['name']
-            actions.append((topic['name'], None, _(topic['name'])))
-            actions.append(('TEST_%s' % topic['name'], None, _(topic['name'])))
-            for lesson_id in topic['lessons']:
-                if self.m_tree.m_visibilities[lesson_id] > self.m_tree.m_visibility:
-                    continue
-                menutitle = self.m_app.lessonfile_manager.m_uiddb[lesson_id]['header']['title']
-                actions.append((
-                    lesson_id, None, menutitle, None, None,
-                    lambda o, e=lesson_id: self.m_app.practise_lesson_id(e)))
-                if self.m_app.lessonfile_manager.is_test_passed(lesson_id):
-                    menutitle = _("%s (passed)") % menutitle
-                if self.m_app.lessonfile_manager.get(lesson_id, 'test'):
+        for menu in self.m_tree.m_menus:
+            self.m_action_groups['NotExit'].add_action(
+                gtk.Action(menu.name, _(menu.name), None, None))
+            s += "<menu action='%s'>" % menu.name
+            for topic in menu.children:
+                s += "<menu action='%s'>" % topic['name']
+                tests += "<menu action='TEST_%s'>" % topic['name']
+                actions.append((topic['name'], None, _(topic['name'])))
+                actions.append(('TEST_%s' % topic['name'], None, _(topic['name'])))
+                for lesson_id in topic.children:
+                    if self.m_tree.m_visibilities[lesson_id] > self.m_tree.m_visibility:
+                        continue
+                    menutitle = self.m_app.lessonfile_manager.m_uiddb[lesson_id]['header']['title']
                     actions.append((
-                        'TEST_%s' % lesson_id, None,
-                        menutitle,
-                        None, None,
-                        lambda o, e=lesson_id: self.m_app.test_lesson_id(e)))
-                    tests += "<menuitem action='TEST_%s' />" % lesson_id
-                s += "<menuitem action='%s' />" % lesson_id
+                        lesson_id, None, menutitle, None, None,
+                        lambda o, e=lesson_id: self.m_app.practise_lesson_id(e)))
+                    if self.m_app.lessonfile_manager.is_test_passed(lesson_id):
+                        menutitle = _("%s (passed)") % menutitle
+                    if self.m_app.lessonfile_manager.get(lesson_id, 'test'):
+                        actions.append((
+                            'TEST_%s' % lesson_id, None,
+                            menutitle,
+                            None, None,
+                            lambda o, e=lesson_id: self.m_app.test_lesson_id(e)))
+                        tests += "<menuitem action='TEST_%s' />" % lesson_id
+                    s += "<menuitem action='%s' />" % lesson_id
+                s += "</menu>"
+                tests += "</menu>"
             s += "</menu>"
-            tests += "</menu>"
         self.m_action_groups['NotExit'].add_actions(actions)
-        s += "</menu>"
         tests += "</menu>"
         s += tests
         s += "</menubar>"
@@ -440,16 +439,16 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
                 })
             import webbrowser
             webbrowser.open_new("http://www.solfege.org?%s" % params)
-    def display_exception_message(self, exception, err_file=None):
+    def display_exception_message(self, exception, err_file=None, msg=None):
         """Call this function only inside an except clause."""
         if err_file:
-            msg = _("Exception catched in %s:%i\n") % (err_file, sys.exc_info()[2].tb_lineno) + "\n"
-        else:
+            msg = _("Exception catched in %s:%i\n") % (err_file, sys.exc_info()[2].tb_lineno)
+        elif not msg:
             msg = ""
         exception_str = unicode(exception)
         if not isinstance(exception_str, unicode):
             exception_str = exception_str.decode(locale.getpreferredencoding(), 'replace')
-        msg = "%s %s" %(msg, exception_str)
+        msg = "\n".join([msg, exception_str])
         m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR,
                               gtk.BUTTONS_CLOSE, msg)
         m.set_title(sys.exc_info()[0].__name__)
@@ -519,15 +518,13 @@ This program is distributed in the hope that it will be useful, but WITHOUT ANY
             assert loc == 'user'
             win.load_file(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename))
         win.show()
-        x, y = win.g_topic_scrollwin.size_request()
-        win.g_lesson_scrollwin.set_size_request(x, int(y*1.6))
-        win.g_deps_scrollwin.set_size_request(x, int(y*1.6))
     def post_constructor(self):
         global splash_win
         self.m_practise_and_test_merge_id = None
         self.m_learning_trees_merge_id = None
         self.on_learning_tree_changed()
         self.create_learning_trees_menu()
+        self.g_ui_manager.add_ui_from_file("help-menu.xml")
         self.box_dict['docviewer'].grab_focus()
         if self.m_app.m_sound_init_exception is not None:
             if splash_win:
