@@ -86,7 +86,7 @@ class Gui(abstract.LessonbasedGui):
             # Invalid key variable or music code goes here.
             exception_cleanup()
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
     def repeat_question(self, widget):
         self.m_t.m_P.play_question()
     def repeat_question_arpeggio(self, widget):
@@ -101,7 +101,7 @@ class Gui(abstract.LessonbasedGui):
             # Invalid key variable or music code goes here.
             soundcard.synth.stop()
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+                self.m_t.m_P._idx, self.m_t.m_lessonfile, e, __file__)
         self.g_new.grab_focus()
     def update_gui_after_lessonfile_change(self):
         self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
