@@ -72,7 +72,7 @@ class Gui(abstract.LessonbasedGui):
             # if the user are fast, that the last question is still playing.
             exception_cleanup()
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
+                self.m_t.m_P._idx, self.m_t.m_lessonfile, e)
         except lessonfile.LessonfileException, e:
             # caused by for example invalid musicformat
             exception_cleanup()
