@@ -221,7 +221,7 @@ class Statistics(AbstractStatistics):
 class LessonStatistics(AbstractStatistics):
     def __init__(self, teacher):
         AbstractStatistics.__init__(self, teacher)
-        self.m_cur_collection = self.m_cur_file = None
+        self.m_cur_file = None
     def enter_test_mode(self):
         """
         We assume that the program has saved and emptied the data dict
@@ -239,7 +239,7 @@ class LessonStatistics(AbstractStatistics):
                 'statistics', self.m_t.m_P.header.lesson_id)
     def get_label_style(self):
         return self.m_t.m_P.header.labelformat
-    def lessonfile_changed(self, new_collection, new_file):
+    def lessonfile_changed(self, new_file):
         if not new_file:
             return
 
@@ -247,7 +247,6 @@ class LessonStatistics(AbstractStatistics):
         self.m_today_stat = {}
         self.m_last7_stat = {}
         self.m_total_stat = {}
-        self.m_cur_collection = new_collection
         self.m_cur_file = new_file
         if not usable_statistics:
             return
@@ -302,9 +301,7 @@ class LessonStatistics(AbstractStatistics):
         else:
             return 0
     def get_hash_of_lessonfile(self):
-        return hash(open(gethomedir.expanduser(os.path.join(
-            self.m_t.get_string('lessoncollections/%s' % self.m_cur_collection),
-            self.m_cur_file))).read())
+        return hash(open(self.m_cur_file).read())
     def key_to_pretty_name(self, key):
         for question in self.m_t.m_P.m_questions:
             if question.get_cname() == key:
